# Qflash JWT Package
a small package for implement jwt security in API


## Getting Started
#### Dependencies
You need Python 3.7 or later to use **qflash_jwt_package**. You can find it at [python.org](https://www.python.org/).


## Features
- File structure for PyPI packages
- Setup with package informations
- License example